===============================
Contributing to django Organice
===============================

Official repositories: (kept in sync)

1. Bitbucket: https://bitbucket.org/bittner/django-organice
#. GitHub: https://github.com/bittner/django-organice

Fork any of the repositories, make your code changes or additions, and place a pull request.

Help Wanted
===========

- Writing tests
- Translations (blog posts, documentation, user interface)

Bumping Versions, Package, Release
==================================

As for the version numbers of django Organice we use `Semantic Versioning <http://semver.org/>`_.
